==> cgtkcalc-2.1.9.tar.gz: cgtkcalc-2.1.9/src/cgtkcalc.h <==
#ifndef __CGTKCALC_H__
#define __CGTKCALC_H__
#include <gtk/gtk.h>
#include <math.h>
#include <stdio.h>
#include <string.h>
#include "zcomplex.h"
/*Fix the size of buffers we use in Clicked.c here.*/
#define CMD_SIZE 10
#define BUF_SIZE 50
/* 4*BUF_SIZE+24 :this is for ACP function.*/
#define F_BUF_SIZE 224
/*This program use "zcomplex" type instead of usual "complex" type.
 *Please see "zcomplex.h".*/

typedef enum { REAL, IMAG, ABSO, ARGU} _InputPos_;
   extern _InputPos_ inputpos; /*position to input to. 0:real 1:imag 2:abs 3:arg*/
/*A sort of mask to specify the label.*/
typedef enum { M_ABS = 32, M_OP = 256} _LabelMask_;
/*Font families*/
typedef enum { F_FIXED, F_CENTURY, F_HELVETICA, F_TIMES,
               BIG_FIXED, BIG_CENTURY, BIG_HELVETICA, BIG_TIMES} _FONTS_;
/*use (0:radian, 1:PIrad, 2:degree) to measure argument.*/
typedef enum { RADIAN, PIRADIAN, DEGREE} _ArgUnit_;
   extern _ArgUnit_ arg_unit;
/*The state which contains input command and complex value*/
typedef struct
{
   zcomplex z;
   /*Command*/
   char cmd[CMD_SIZE];
   /*The priority of cmd*/
   int pr;
} typInputs;
/*the maximum value of priority.*/
#define N_PR 4
/*Stack of input value and input command for each priority level
 *for binary operators.*/
extern typInputs bufinputs[N_PR];

/*Following variables are defined in "variables.c".*/
extern zcomplex cz;/*currently displayed complex value*/
extern zcomplex mz;/* mz: memorized value*/
extern char prevCmd[CMD_SIZE];/*previously input binary command*/

typedef struct
{
   zcomplex cz;/*complex value*/
   zcomplex mz;/*complex value for memory*/
   int is_hidden_m;/*whether memory is hidden or not.*/
   int p_count;/*the number of parentheses*/
   typInputs inputs[N_PR];
   char prevCmd[CMD_SIZE];
} memInputs;
/*N_MI: the maximum number of memorized input states.*/
/*N_MI > N_P_B - 1, N_P_B is defined in "parenthesis.h"*/
#define N_MI 11
extern memInputs buf_state[N_MI];/* buf_state: memorized state for UNDO*/
extern int n_memInputs;

/*Sort of buttons*/
typedef enum { DIGITS, UNARY_OP, BINARY_OP, OTHERS, TOGGLE_B} _Sort_;

typedef struct
{
  char *szLabel;
  int row;
  int col;
  int width;
  _Sort_ sort;/*<sort>
   0:digits, 1:unary operators,
   2:binary operators, 3:others,
   4:toggle buttons */
  GtkWidget *widget;
  int pr;/*<priority of the operator>
   0:no operation, 1>2>3>4>5>6>...*/
} typCalculatorButton;
  extern typCalculatorButton buttonList[];
  extern int nButtons;  /*defined in "ButtonList.c"*/
#include "ButtonList.h" /*get the list of button numbers*/

extern GtkWidget *labelRe;  extern GtkWidget *labelIm;
extern GtkWidget *labelAbs; extern GtkWidget *labelArg;
extern GtkWidget *event_boxRe;  extern GtkWidget *event_boxIm;
extern GtkWidget *event_boxAbs; extern GtkWidget *event_boxArg;
  /*These are defined in "CreateLabels.c"*/

void QuitApp (GtkWidget *widget, gpointer data);
GtkStyle *CreateStyle (int stv);
void RenewLabels();

#endif/*__CGTKCALC_H__*/

==> cgtkcalc-2.2.4.tar.gz: cgtkcalc-2.2.4/src/cgtkcalc.h <==
#ifndef __CGTKCALC_H__
#define __CGTKCALC_H__
#include <gtk/gtk.h>
#include <math.h>
#include <stdio.h>
#include <string.h>
#include "zcomplex.h"
/*Fix the size of buffers we use in Clicked.c here.*/
#define CMD_SIZE 10
#define BUF_SIZE 50
/* 4*BUF_SIZE+24 :this is for ACP function.*/
#define F_BUF_SIZE 224
/*This program use "zcomplex" type instead of usual "complex" type.
 *Please see "zcomplex.h".*/

typedef enum { REAL, IMAG, ABSO, ARGU} _InputPos_;
   extern _InputPos_ inputpos; /*position to input to. 0:real 1:imag 2:abs 3:arg*/
/*A sort of mask to specify the label.*/
typedef enum { M_ABS = 32, M_OP = 256} _LabelMask_;
/*Font families*/
typedef enum { F_FIXED, F_CENTURY, F_HELVETICA, F_TIMES,
               BIG_FIXED, BIG_CENTURY, BIG_HELVETICA, BIG_TIMES} _FONTS_;
/*use (0:radian, 1:PIrad, 2:degree) to measure argument.*/
typedef enum { RADIAN, PIRADIAN, DEGREE} _ArgUnit_;
   extern _ArgUnit_ arg_unit;
/*The state which contains input command and complex value*/
typedef struct
{
   zcomplex z;
   /*Command*/
   char cmd[CMD_SIZE];
   /*The priority of cmd*/
   int pr;
} typInputs;
/*the maximum value of priority.*/
#define N_PR 4
/*Stack of input value and input command for each priority level
 *for binary operators.*/
extern typInputs bufinputs[N_PR];

/*Following variables are defined in "variables.c".*/
extern zcomplex cz;/*currently displayed complex value*/
extern zcomplex mz;/* mz: memorized value*/
extern char prevCmd[CMD_SIZE];/*previously input binary command*/

typedef struct
{
   zcomplex cz;/*complex value*/
   zcomplex mz;/*complex value for memory*/
   int is_hidden_m;/*whether memory is hidden or not.*/
   int p_count;/*the number of parentheses*/
   typInputs inputs[N_PR];
   char prevCmd[CMD_SIZE];
} memInputs;
/*N_MI: the maximum number of memorized input states.*/
/*N_MI > N_P_B - 1, N_P_B is defined in "parenthesis.h"*/
#define N_MI 11
extern memInputs buf_state[N_MI];/* buf_state: memorized state for UNDO*/
extern int n_memInputs;

/*Sort of buttons*/
typedef enum { DIGITS, UNARY_OP, BINARY_OP, OTHERS, TOGGLE_B, COVERS} _Sort_;

typedef struct
{
  char *szLabel;
  int row;
  int col;
  int width;
  _Sort_ sort;/*<sort>
   0:digits, 1:unary operators,
   2:binary operators, 3:others,
   4:toggle buttons */
  GtkWidget *widget;
  int pr;/*<priority of the operator>
   0:no operation, 1>2>3>4>5>6>...*/
} typCalculatorButton;
  extern typCalculatorButton buttonList[];
  extern int nButtons;  /*defined in "ButtonList.c"*/
#include "ButtonList.h" /*get the list of button numbers*/

extern GtkWidget *labelRe;  extern GtkWidget *labelIm;
extern GtkWidget *labelAbs; extern GtkWidget *labelArg;
extern GtkWidget *event_boxRe;  extern GtkWidget *event_boxIm;
extern GtkWidget *event_boxAbs; extern GtkWidget *event_boxArg;
  /*These are defined in "CreateLabels.c"*/

void QuitApp (GtkWidget *widget, gpointer data);
GtkStyle *CreateStyle (int stv);
void RenewLabels();

#endif/*__CGTKCALC_H__*/
